==> cloudrail_knowledge-0.0.7-py3-none-any.whl: cloudrail/knowledge/rules/aws/context_aware/public_access_validation_rules/public_access_dms_replication_instance_rule.py <==
from typing import Dict, List

from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
from cloudrail.knowledge.utils.connection_utils import ConnectionUtils
from cloudrail.knowledge.context.environment_context import EnvironmentContext
from cloudrail.knowledge.rules.base_rule import Issue
from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType


class PublicAccessDmsReplicationInstanceRule(AwsBaseRule):

    def get_id(self) -> str:
        return 'public_access_dms_replication_instance'

    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
        issues: List[Issue] = []

        for dms_instance in env_context.dms_replication_instances:
            security_group = ConnectionUtils.get_allowing_public_access_portless(dms_instance)
            if security_group:
                issues.append(Issue(
                    f'~Internet~. '
                    f"Instance `{dms_instance.get_friendly_name()}` is on "
                    f"{dms_instance.network_resource.vpc.get_type()}"
                    f" `{dms_instance.network_resource.vpc.get_friendly_name()}`. "
                    f"{dms_instance.get_type()} uses subnet(s) "
                    f"`{', '.join([x.get_friendly_name() for x in dms_instance.network_resource.subnets])}`. "
                    f"{dms_instance.get_type()} is reachable from the internet due to subnet(s) and route table(s). "
                    f"Subnet uses Network ACL(s) "
                    f"`{', '.join({x.network_acl.get_friendly_name() for x in dms_instance.network_resource.subnets})}`. "
                    f"Network ACL's and security group(s) allows access to the {dms_instance.get_type()}. "
                    f'~{dms_instance.get_type()}~',
                    dms_instance, security_group))
        return issues

    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
        return bool(environment_context.dms_replication_instances)

==> cloudrail_knowledge-0.0.20b4-py3-none-any.whl: cloudrail/knowledge/rules/aws/context_aware/public_access_validation_rules/public_access_dms_replication_instance_rule.py <==
from typing import Dict, List

from cloudrail.knowledge.rules.aws.aws_base_rule import AwsBaseRule
from cloudrail.knowledge.utils.connection_utils import get_allowing_public_access_portless
from cloudrail.knowledge.context.environment_context import EnvironmentContext
from cloudrail.knowledge.rules.base_rule import Issue
from cloudrail.knowledge.rules.rule_parameters.base_paramerter import ParameterType


class PublicAccessDmsReplicationInstanceRule(AwsBaseRule):

    def get_id(self) -> str:
        return 'public_access_dms_replication_instance'

    def execute(self, env_context: EnvironmentContext, parameters: Dict[ParameterType, any]) -> List[Issue]:
        issues: List[Issue] = []

        for dms_instance in env_context.dms_replication_instances:
            security_group = get_allowing_public_access_portless(dms_instance)
            if security_group:
                issues.append(Issue(
                    f'~Internet~. '
                    f"Instance `{dms_instance.get_friendly_name()}` is on "
                    f"{dms_instance.network_resource.vpc.get_type()}"
                    f" `{dms_instance.network_resource.vpc.get_friendly_name()}`. "
                    f"{dms_instance.get_type()} uses subnet(s) "
                    f"`{', '.join([x.get_friendly_name() for x in dms_instance.network_resource.subnets])}`. "
                    f"{dms_instance.get_type()} is reachable from the internet due to subnet(s) and route table(s). "
                    f"Subnet uses Network ACL(s) "
                    f"`{', '.join({x.network_acl.get_friendly_name() for x in dms_instance.network_resource.subnets})}`. "
                    f"Network ACL's and security group(s) allows access to the {dms_instance.get_type()}. "
                    f'~{dms_instance.get_type()}~',
                    dms_instance, security_group))
        return issues

    def should_run_rule(self, environment_context: EnvironmentContext) -> bool:
        return bool(environment_context.dms_replication_instances)
